netapp_ontap.models.ems_event_action_parameters API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ems_event_action_parameters`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class EmsEventActionParametersSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the EmsEventActionParameters object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `description: EmsUiMessage GET`

    Information to be displayed to the user.

  `enum: List[str] GET`

    Specifies the possible values of the parameter.

    Example: ["value-1","value-2"]

  `exclusive_maximum: bool GET`

    Specifies whether the "maximum" value is excluded in the parameter value range.

  `exclusive_minimum: bool GET`

    Specifies whether the "minimum" value is excluded in the parameter value range.

  `format: str GET`

    An optional modifier that serves as a hint at the content and format of the parameter.

    Example: date-time

  `help: EmsUiMessage GET`

    Information to be displayed to the user.

  `in_: str GET`

    Specifies where the parameter is placed when invoking the action.

    Valid choices:

    - body
    - query
  `items: Dict GET`

    If the type of the parameter is an array, this specifies the type of items in the form of a JSON object where other properties applicable to that type can be included.

    Example: {"format":"date-time","type":"string"}

  `max_items: Size GET`

    Specifies the maximum length of an array type parameter.

  `max_length: Size GET`

    Specifies the maximum length of a string type parameter.

  `maximum: Size GET`

    Specifies the maximum value of the parameter.

  `min_items: Size GET`

    Specifies the minimum length of an array type parameter.

  `min_length: Size GET`

    Specifies the minimum length of a string type parameter.

  `minimum: Size GET`

    Specifies the minimum value of the parameter.

  `multiple_of: float GET`

    Specifies that a number type parameter must be the multiple of this number.

  `name: str GET`

    Parameter name.

    Example: schedule-at

  `optional: List[str] GET`

    By default, all properties of an object type parameter are mandatory. This property specifies the list of optional properties.

    Example: ["end-time"]

  `pattern: str GET`

    Specifies a regular expression template for a string type parameter.

  `properties: Dict GET`

    If the type of the parameter is an object, this specifies what properties make up the object in the form of a JSON array where multiple parameters can be embedded within a single parameter. It is primarily used as a schema for an array type parameter.

    Example: [{"format":"date-time","name":"start-date","type":"string"},{"format":"date-time","name":"end-date","type":"string"}]

  `title: EmsUiMessage GET`

    Information to be displayed to the user.

  `type: str GET`

    Parameter type.

    Valid choices:

    - string
    - number
    - integer
    - boolean
    - array
    - object
  `unique_items: bool GET`

    Specifies whether the "maximum" value is excluded in the parameter value range.

  `validation_error_message: EmsUiMessage GET`

    Information to be displayed to the user.

  `value: Dict GET`

    Specifies the current value(s) for the parameter encoded in the appropriate JSON type.